<?php
/**
* Plugin Name:       Google Analytics alternative – Privacy and legally compliant – Fair Analytics
* Plugin URI:        https://wordpress.org/plugins/fairanalytics
* Description:       Enables Fair Analytics on your website. To analyze your visitor data we integrate a small javascript code into the header of your website.
* Version:           1.0.9
* Requires at least: 5.2
* Requires PHP:      7.2
* Author:            Fair Analytics
* Author URI:        https://www.fairanalytics.de/
* License:           GPLv3 and Higher
* License URI:       https://www.gnu.org/licenses/gpl-3.0.html
* Text Domain:       fair-analytics
* Domain Path:       fairanalytics
*/

namespace dsgvo_analytic;

if ( ! defined( 'ABSPATH' ) ) {
    die("Direct access not allowed");
    exit; // Exit if accessed directly
}


define('DSGVO_Analytic_Author_URI', 'https://www.fairanalytics.de');
define('DSGVO_Analytic_Author_Contact_URI', 'https://www.fairanalytics.de/kontakt');
define('DSGVO_Analytic_Author_Registration_URI', 'https://www.fairanalytics.de');
define('DSGVO_Analytic_DIR', plugin_dir_path(__FILE__));
define('DSGVO_Analytic_URI', plugin_dir_url(__FILE__));
define('DSGVO_Analytic_SLUG', 'dsgvo-analytics');
define('DSGVO_Analytic_ID', 'dsgvo-analytics-ID');
define('DSGVO_Analytic_ID_Placeholder', '');
define('DSGVO_Analytic_Service', 'dsgvo-analytics-service');

define('DSGVO_Analytic_location', array('options-general.php','settings_page_'.DSGVO_Analytic_SLUG.''));
define('DSGVO_Analytic_setting_url', ''.get_site_url().'/wp-admin/options-general.php?page=dsgvo-analytics');


register_uninstall_hook( __FILE__, 'dsgvo_analytic\uninstall_dsgvo_analytics' );
register_deactivation_hook( __FILE__, 'dsgvo_analytic\deactive_dsgvo_analytics' );
register_activation_hook( __FILE__, 'dsgvo_analytic\active_dsgvo_analytics' );


function uninstall_dsgvo_analytics(){
	delete_option('dsgvo-analytics-ID');
	delete_option('dsgvo-analytics-service');
}
function deactive_dsgvo_analytics(){
//
}
function active_dsgvo_analytics(){
	if(empty(get_option(DSGVO_Analytic_ID)))
		update_option(DSGVO_Analytic_ID,DSGVO_Analytic_ID_Placeholder);
	if(empty(get_option(DSGVO_Analytic_Service)) || !get_option(DSGVO_Analytic_Service))
		update_option(DSGVO_Analytic_Service,0);
}

function dsgvo_analytic_plugin_load_textdomain() {
load_plugin_textdomain( 'fair-analytics', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'init', 'dsgvo_analytic\dsgvo_analytic_plugin_load_textdomain' );



$wpr = new DSGVO_analytic();
Class DSGVO_analytic{
	public function __construct(){
		add_action( "wp_ajax_nopriv_dsgvo_analytic_active_service", array( $this, 'dsgvo_analytic_active_service' ) );
		add_action( "wp_ajax_dsgvo_analytic_active_service",        array( $this, 'dsgvo_analytic_active_service' ) );
		add_action( "wp_ajax_nopriv_dsgvo_analytic_js_ID", array( $this, 'dsgvo_analytic_js_ID' ) );
		add_action( "wp_ajax_dsgvo_analytic_js_ID",        array( $this, 'dsgvo_analytic_js_ID' ) );
		add_action('in_admin_header', array($this,'dsgvo_analytic_remove_notice'));
		add_action('admin_menu', array($this,'dsgvo_analytic_register_menu'));
		add_action('admin_enqueue_scripts', array($this,'dsgvo_analytic_enqueue_admin'));
		add_action( 'wp_head', array($this,'dsgvo_analytic_js_variable') );
		// add_action('wp_enqueue_scripts',array($this,'dsgvo_analytic_js_variable'));
		//add_filter( 'plugin_row_meta', array($this,'dsgvo_plugin_row_meta'), 10, 2 );
		add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array($this,'dsgvo_plugin_row_meta') );

		// add_filter( 'script_loader_tag', array($this,'dsgvo_analytic_add_id'), 10, 3 );

	}



	// Add data domain Id in to script tag function end here


	function dsgvo_plugin_row_meta( $links ){



	    $url = DSGVO_Analytic_setting_url;

	    $_link = array('<a href="'.$url.'">Settings</a>');

	    $actions = array_merge( $_link, $links );

	    return $actions;
	}

	public function dsgvo_analytic_js_variable(){
		$js_ID = get_option(DSGVO_Analytic_ID);
		$js_ID = htmlspecialchars_decode(stripslashes( base64_decode($js_ID)));
		$DSGVO_Analytic_Service = get_option(DSGVO_Analytic_Service);
		if( !empty( $js_ID ) && $js_ID != DSGVO_Analytic_ID_Placeholder && ( !empty( $DSGVO_Analytic_Service ) && $DSGVO_Analytic_Service ) ){
			//  echo '<script async defer data-secure-id="'.$js_ID.'" src="https://fairdatacenter.de/cdn/fair.js"></script>';

			echo $js_ID;
		}
	}


	public function dsgvo_analytic_remove_notice(){
		if ( $this->is_dsgvo_analytic() ) {
			remove_all_actions('admin_notices');
			remove_all_actions('all_admin_notices');
		}
	}
	public function dsgvo_analytic_register_menu(){
		add_submenu_page( ''.DSGVO_Analytic_location[0].'', 'Fair Analytics', 'Fair Analytics', 'manage_options', DSGVO_Analytic_SLUG, array($this,'dsgvo_analytic_setting_page') );
	}
	public function dsgvo_analytic_setting_page(){
		require_once DSGVO_Analytic_DIR . 'template/main_page.php';
	}
	public function dsgvo_analytic_enqueue_admin(){
		if ( $this->is_dsgvo_analytic() ) {
			wp_enqueue_style(''.DSGVO_Analytic_SLUG.'-admin-style', DSGVO_Analytic_URI.'assets/css/admin-style.css', null, '1.1');
			wp_register_script( ''.DSGVO_Analytic_SLUG.'-admin-functions-js', DSGVO_Analytic_URI.'assets/js/admin-functions.js', [ 'jquery' ] );
			wp_localize_script( ''.DSGVO_Analytic_SLUG.'-admin-functions-js', 'DSGVO_analytic', [ 'ajaxurl' => admin_url('admin-ajax.php' ) ] );
			wp_enqueue_script( ''.DSGVO_Analytic_SLUG.'-admin-functions-js' );
		}
	}
	public function dsgvo_analytic_js_ID(){
		if(empty($_POST["id"]) && get_option(DSGVO_Analytic_ID) == DSGVO_Analytic_ID_Placeholder ){
      $err_msg = esc_html__('Please enter your tracking code.', 'fair-analytics');
			echo json_encode(array('status'=>false, 'message'=> $err_msg));
		}else{

			$js_ID = $_POST["id"];
			if(empty($js_ID)){
				update_option(DSGVO_Analytic_Service,0);
				$js_ID = DSGVO_Analytic_ID_Placeholder;
			}

			update_option(DSGVO_Analytic_ID, base64_encode($js_ID));
			update_option("ch_js", base64_encode($js_ID));

			$sanitize_id = $_POST['id'];
			echo json_encode(array( 'status'=>true, 'service_deactive'=>(empty($sanitize_id)) ? true:false ));

		}
		die();
	}
	public function dsgvo_analytic_active_service(){


		$DSGVO_Analytic_ID = get_option(DSGVO_Analytic_ID);
		if(!empty($DSGVO_Analytic_ID) && $DSGVO_Analytic_ID != DSGVO_Analytic_ID_Placeholder){
			$sanitize_service = sanitize_text_field($_POST["service"]);
			update_option(DSGVO_Analytic_Service, $sanitize_service);
			echo json_encode(array('status'=>true));
		}else{
			$err_msg = esc_html__('Please enter your tracking code first.', 'fair-analytics');
      echo json_encode(array('status'=>false, 'message'=> $err_msg));
		}
		die();
	}
	public function is_dsgvo_analytic(){
		$screen = get_current_screen();
		if ( $screen->base == DSGVO_Analytic_location[1] ) {
			return true;
		}else{
			return false;
		}
	}
}
